autocert

package module
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2026 License: MIT Imports: 12 Imported by: 0

README

autocert

A package that makes some improvements to golang.org/x/crypto/acme/autocert.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Listen

func Listen(network, address string, config *Config) (net.Listener, error)

Listen is used to listen a TLS listener with ACME.

func ListenContext

func ListenContext(ctx context.Context, network, address string, config *Config) (net.Listener, error)

ListenContext is used to listen a TLS listener with context.

func NewListener added in v1.1.0

func NewListener(ctx context.Context, listener net.Listener, config *Config) (net.Listener, error)

NewListener is used to create ACME listener from income listener.

Types

type Config

type Config struct {
	Domains   []string
	IPAddrs   []string
	Cache     certmgr.Cache
	Client    *acme.Client
	TLSConfig *tls.Config
}

Config contains configuration about ACME Manager.

Directories

Path Synopsis
Package acme provides an implementation of the Automatic Certificate Management Environment (ACME) spec, most famously used by Let's Encrypt.
Package acme provides an implementation of the Automatic Certificate Management Environment (ACME) spec, most famously used by Let's Encrypt.
Package certmgr provides automatic access to certificates from Let's Encrypt and any other ACME-based CA.
Package certmgr provides automatic access to certificates from Let's Encrypt and any other ACME-based CA.
internal/acmetest
Package acmetest provides types for testing acme and autocert packages.
Package acmetest provides types for testing acme and autocert packages.

Jump to